CREATE TABLE "platform_users" (
  "ID" int DEFAULT NULL,
  "username" varchar(60) NOT NULL,
  CONSTRAINT "PriKey_platform_users" PRIMARY KEY ("username")
);

INSERT INTO "platform_users" ("username") VALUES ('Admin');

CREATE TABLE "platform_groups" (
  "ID" int DEFAULT NULL,
  "groupname" varchar(60) NOT NULL,
  CONSTRAINT "PriKey_platform_groups" PRIMARY KEY ("groupname")
);

CREATE TABLE "col_files_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_col_files_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_files_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_files_folders" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "parent" int DEFAULT NULL,
  "name" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_col_files_folders" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_files_folders_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_files_folders_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_files_folders_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_files_files" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "folder" int NOT NULL,
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "filenum" varchar(255) DEFAULT NULL,
  "status" smallint DEFAULT '0',
  "description" text DEFAULT NULL,
  "versioncount" int DEFAULT '0',
  CONSTRAINT "PriKey_col_files_files" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_files_files_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_files_files_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_files_files_folder" FOREIGN KEY ("folder") REFERENCES "col_files_folders" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_files_files_category" FOREIGN KEY ("category") REFERENCES "col_files_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_files_items" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "file" int NOT NULL,
  "filename" varchar(255) DEFAULT NULL,
  "version" varchar(255) DEFAULT NULL,
  "mimetype" varchar(255) DEFAULT NULL,
  "size" int DEFAULT '0',
  "comment" text DEFAULT NULL,
  "binfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_col_files_items" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_files_items_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_files_items_file" FOREIGN KEY ("file") REFERENCES "col_files_files" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_files_journal" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "file" int NOT NULL,
  "date" int DEFAULT '0',
  "subject" varchar(255) DEFAULT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_col_files_journal" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_files_journal_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_files_journal_file" FOREIGN KEY ("file") REFERENCES "col_files_files" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_files_shortcuts" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) NOT NULL,
  "creationdate" int DEFAULT '0',
  "file" int NOT NULL,
  CONSTRAINT "PriKey_col_files_shortcuts" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_files_shortcuts_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_files_shortcuts_file" FOREIGN KEY ("file") REFERENCES "col_files_files" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_forums_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_col_forums_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_forums_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_forums_forums" (
  "ID" serial NOT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "category" int DEFAULT NULL,
  "name" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  "lastentry" int DEFAULT '0',
  CONSTRAINT "PriKey_col_forums_forums" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_forums_forums_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_forums_forums_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_forums_forums_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_forums_forums_category" FOREIGN KEY ("category") REFERENCES "col_forums_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_forums_topics" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "forum" int NOT NULL,
  "title" varchar(255) DEFAULT NULL,
  "lastentry" int DEFAULT '0',
  CONSTRAINT "PriKey_col_forums_topics" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_forums_topics_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_forums_topics_forum" FOREIGN KEY ("forum") REFERENCES "col_forums_forums" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_forums_entries" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "topic" int NOT NULL,
  "flag" smallint DEFAULT '0',
  "text" text DEFAULT NULL,
  "attachname" varchar(255) DEFAULT NULL,
  "attachmimetype" varchar(255) DEFAULT NULL,
  "attachbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_col_forums_entries" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_forums_entries_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_forums_entries_topic" FOREIGN KEY ("topic") REFERENCES "col_forums_topics" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_forums_notify" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) NOT NULL,
  "forum" int NOT NULL,
  CONSTRAINT "PriKey_col_forums_notify" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_forums_notify_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_forums_notify_forum" FOREIGN KEY ("forum") REFERENCES "col_forums_forums" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_forums_view" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) NOT NULL,
  "forum" int NOT NULL,
  CONSTRAINT "PriKey_col_forums_view" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_forums_view_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_forums_view_forum" FOREIGN KEY ("forum") REFERENCES "col_forums_forums" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_messages_folders" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "parent" int DEFAULT NULL,
  "name" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_col_messages_folders" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_messages_folders_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_folders_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_folders_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_messages_accounts" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) NOT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "activity" smallint DEFAULT '0',
  "default" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "email" varchar(255) DEFAULT NULL,
  "server" varchar(255) DEFAULT NULL,
  "port" smallint DEFAULT '0',
  "protocol" varchar(255) DEFAULT NULL,
  "username" varchar(255) DEFAULT NULL,
  "password" varchar(255) DEFAULT NULL,
  "movetoprimary" smallint DEFAULT '0',
  "moveto" int DEFAULT NULL,
  "description" text DEFAULT NULL,
  "leavemsg" smallint DEFAULT '0',
  "folder_drafts" varchar(255) DEFAULT NULL,
  "folder_outbox" varchar(255) DEFAULT NULL,
  "folder_sent" varchar(255) DEFAULT NULL,
  "usefolder_trash" smallint DEFAULT '0',
  "folder_trash" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_col_messages_accounts" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_messages_accounts_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_accounts_moveto" FOREIGN KEY ("moveto") REFERENCES "col_messages_folders" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_messages_templates" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "default" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_col_messages_templates" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_messages_templates_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_templates_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_templates_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_messages_mailinglists" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "template" int DEFAULT NULL,
  "title" varchar(255) DEFAULT NULL,
  "status" smallint DEFAULT '0',
  "subject" varchar(255) DEFAULT NULL,
  "sender" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_col_messages_mailinglists" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_messages_mailinglists_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_mailinglists_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_mailinglists_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_mailinglists_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_mailinglists_template" FOREIGN KEY ("template") REFERENCES "col_messages_templates" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_contacts_companies" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60)  DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "deleted" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "director" varchar(255) DEFAULT NULL,
  "traderegister" varchar(255) DEFAULT NULL,
  "taxcode" varchar(255) DEFAULT NULL,
  "address" varchar(255) DEFAULT NULL,
  "postalcode" varchar(255) DEFAULT NULL,
  "city" varchar(255) DEFAULT NULL,
  "region" varchar(255) DEFAULT NULL,
  "country" varchar(255) DEFAULT NULL,
  "phone" varchar(255) DEFAULT NULL,
  "phone2" varchar(255) DEFAULT NULL,
  "fax" varchar(255) DEFAULT NULL,
  "fax2" varchar(255) DEFAULT NULL,
  "email" varchar(255) DEFAULT NULL,
  "website" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_org_contacts_companies" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_contacts_companies_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_companies_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_companies_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_companies_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_messages_companies" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "mailinglist" int NOT NULL,
  "company" int NOT NULL,
  CONSTRAINT "PriKey_col_messages_companies" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_messages_companies_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_companies_mailinglist" FOREIGN KEY ("mailinglist") REFERENCES "col_messages_mailinglists" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_companies_company" FOREIGN KEY ("company") REFERENCES "org_contacts_companies" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_messages_mailings" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "mailinglist" int NOT NULL,
  "flag" smallint DEFAULT '0',
  "date" int DEFAULT '0',
  "subject" varchar(255) DEFAULT NULL,
  "sender" varchar(255) DEFAULT NULL,
  "sender_name" varchar(255) DEFAULT NULL,
  "contenttype" varchar(255) DEFAULT NULL,
  "abstract" text DEFAULT NULL,
  "binfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_col_messages_mailings" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_messages_mailings_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_mailings_mailinglist" FOREIGN KEY ("mailinglist") REFERENCES "col_messages_mailinglists" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_messages_messages" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "account" int DEFAULT NULL,
  "primaryfolder" smallint DEFAULT '0',
  "folder" int DEFAULT NULL,
  "flag" smallint DEFAULT '0',
  "date" int DEFAULT '0',
  "subject" varchar(255) DEFAULT NULL,
  "sender" varchar(255) DEFAULT NULL,
  "sender_name" varchar(255) DEFAULT NULL,
  "to" varchar(255) DEFAULT NULL,
  "to_name" varchar(255) DEFAULT NULL,
  "cc" varchar(255) DEFAULT NULL,
  "bcc" varchar(255) DEFAULT NULL,
  "reply_to" varchar(255) DEFAULT NULL,
  "count_to" int DEFAULT '0',
  "contenttype" varchar(255) DEFAULT NULL,
  "abstract" text DEFAULT NULL,
  "answeredmessage" int DEFAULT NULL,
  "binfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_col_messages_messages" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_messages_messages_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_messages_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_messages_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_messages_account" FOREIGN KEY ("account") REFERENCES "col_messages_accounts" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_messages_folder" FOREIGN KEY ("folder") REFERENCES "col_messages_folders" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_messages_msglog" (
  "ID" serial NOT NULL,
  "account" int NOT NULL,
  "uid" int DEFAULT '0',
  CONSTRAINT "PriKey_col_messages_msglog" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_messages_msglog_account" FOREIGN KEY ("account") REFERENCES "col_messages_accounts" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_contacts_people" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "deleted" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "lastname" varchar(255) DEFAULT NULL,
  "firstname" varchar(255) DEFAULT NULL,
  "title" varchar(255) DEFAULT NULL,
  "company" varchar(255) DEFAULT NULL,
  "position" varchar(255) DEFAULT NULL,
  "workgroup" varchar(255) DEFAULT NULL,
  "address" varchar(255) DEFAULT NULL,
  "postalcode" varchar(255) DEFAULT NULL,
  "city" varchar(255) DEFAULT NULL,
  "region" varchar(255) DEFAULT NULL,
  "country" varchar(255) DEFAULT NULL,
  "phone" varchar(255) DEFAULT NULL,
  "phone2" varchar(255) DEFAULT NULL,
  "cell" varchar(255) DEFAULT NULL,
  "fax" varchar(255) DEFAULT NULL,
  "fax2" varchar(255) DEFAULT NULL,
  "pager" varchar(255) DEFAULT NULL,
  "iptel" varchar(255) DEFAULT NULL,
  "email" varchar(255) DEFAULT NULL,
  "usebirthdate" smallint DEFAULT '0',
  "birthdate" int DEFAULT '0',
  "description" text DEFAULT NULL,
  "picbinfile" varchar(32) DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_org_contacts_people" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_contacts_people_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_people_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_people_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_people_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_messages_people" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "mailinglist" int NOT NULL,
  "person" int NOT NULL,
  CONSTRAINT "PriKey_col_messages_people" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_messages_people_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_people_mailinglist" FOREIGN KEY ("mailinglist") REFERENCES "col_messages_mailinglists" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_messages_people_person" FOREIGN KEY ("person") REFERENCES "org_contacts_people" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_news_channels" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "type" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "newsfeed" varchar(255) DEFAULT NULL,
  "link" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_col_news_channels" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_news_channels_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_news_channels_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_news_channels_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_news_newsitems" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "channel" int DEFAULT NULL,
  "title" varchar(255) DEFAULT NULL,
  "pubdate" int DEFAULT '0',
  "link" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_col_news_newsitems" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_news_newsitems_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_news_newsitems_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_news_newsitems_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_news_newsitems_channel" FOREIGN KEY ("channel") REFERENCES "col_news_channels" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "col_news_view" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) NOT NULL,
  "channel" int NOT NULL,
  CONSTRAINT "PriKey_col_news_view" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_col_news_view_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_col_news_view_channel" FOREIGN KEY ("channel") REFERENCES "col_news_channels" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_customers_customers" (
  "ID" serial NOT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "person" int DEFAULT NULL,
  "company" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "customernum" varchar(255) DEFAULT NULL,
  "risk" smallint DEFAULT '0',
  "dispatch" smallint DEFAULT '0',
  "payment" smallint DEFAULT '0',
  "prefcontact" smallint DEFAULT '0',
  "description" text DEFAULT NULL,
  "usebilling" smallint DEFAULT '0',
  "billingaddr" varchar(255) DEFAULT NULL,
  "billingpc" varchar(255) DEFAULT NULL,
  "billingcity" varchar(255) DEFAULT NULL,
  "billingcountry" varchar(255) DEFAULT NULL,
  "useshipping" smallint DEFAULT '0',
  "shippingaddr" varchar(255) DEFAULT NULL,
  "shippingpc" varchar(255) DEFAULT NULL,
  "shippingcity" varchar(255) DEFAULT NULL,
  "shippingcountry" varchar(255) DEFAULT NULL,
  "bank" varchar(255) DEFAULT NULL,
  "bankid" varchar(255) DEFAULT NULL,
  "account" varchar(255) DEFAULT NULL,
  "cctype" smallint DEFAULT '0',
  "ccnum" varchar(255) DEFAULT NULL,
  "ccvalid" varchar(5) DEFAULT NULL,
  "ccauth" varchar(3) DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_customers_customers" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_customers_customers_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_customers_customers_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_customers_customers_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_customers_customers_person" FOREIGN KEY ("person") REFERENCES "org_contacts_people" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_customers_customers_company" FOREIGN KEY ("company") REFERENCES "org_contacts_companies" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_billing_deliveries" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "customer" int DEFAULT NULL,
  "deliverynum" varchar(255) DEFAULT NULL,
  "date" int DEFAULT '0',
  "status" smallint DEFAULT '0',
  "discount" double precision DEFAULT '0',
  "netamount" double precision DEFAULT '0',
  "tax" double precision DEFAULT '0',
  "itemsbinfile" varchar(32) DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_billing_deliveries" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_billing_deliveries_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_billing_deliveries_customer" FOREIGN KEY ("customer") REFERENCES "crm_customers_customers" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_billing_invoices" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "customer" int DEFAULT NULL,
  "invoicenum" varchar(255) DEFAULT NULL,
  "date" int DEFAULT '0',
  "duedate" int DEFAULT '0',
  "status" smallint DEFAULT '0',
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_billing_invoices" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_billing_invoices_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_billing_invoices_customer" FOREIGN KEY ("customer") REFERENCES "crm_customers_customers" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_billing_invoices_deliveries" (
  "ID" serial NOT NULL,
  "invoice" int NOT NULL,
  "delivery" int NOT NULL,
  CONSTRAINT "PriKey_crm_billing_invoices_deliveries" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_billing_invoices_deliveries_invoice" FOREIGN KEY ("invoice") REFERENCES "crm_billing_invoices" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_billing_invoices_deliveries_delivery" FOREIGN KEY ("delivery") REFERENCES "crm_billing_deliveries" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_billing_offers" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "customer" int DEFAULT NULL,
  "quotationnum" varchar(255) DEFAULT NULL,
  "date" int DEFAULT '0',
  "duedate" int DEFAULT '0',
  "status" smallint DEFAULT '0',
  "discount" double precision DEFAULT '0',
  "netamount" double precision DEFAULT '0',
  "tax" double precision DEFAULT '0',
  "margin" double precision DEFAULT '0',
  "itemsbinfile" varchar(32) DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_billing_offers" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_billing_offers_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_billing_offers_customer" FOREIGN KEY ("customer") REFERENCES "crm_customers_customers" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_billing_orders" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "customer" int DEFAULT NULL,
  "ordernum" varchar(255) DEFAULT NULL,
  "date" int DEFAULT '0',
  "duedate" int DEFAULT '0',
  "status" smallint DEFAULT '0',
  "discount" double precision DEFAULT '0',
  "netamount" double precision DEFAULT '0',
  "tax" double precision DEFAULT '0',
  "margin" double precision DEFAULT '0',
  "itemsbinfile" varchar(32) DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_billing_orders" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_billing_orders_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_billing_orders_customer" FOREIGN KEY ("customer") REFERENCES "crm_customers_customers" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_billing_payments" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "invoice" int NOT NULL,
  "date" int DEFAULT '0',
  "account" varchar(255) DEFAULT NULL,
  "reference" varchar(255) DEFAULT NULL,
  "amount" double precision DEFAULT '0',
  CONSTRAINT "PriKey_crm_billing_payments" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_billing_payments_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_billing_payments_invoice" FOREIGN KEY ("invoice") REFERENCES "crm_billing_invoices" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_billing_templates" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "type" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  "inputbinfile" varchar(32) DEFAULT NULL,
  "outputbinfile" varchar(32) DEFAULT NULL,
  "pdfbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_billing_templates" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_billing_templates_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_billing_printouts" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "type" smallint DEFAULT '0',
  "transaction" int NOT NULL,
  "transactionnum" varchar(255) DEFAULT NULL,
  "template" int DEFAULT NULL,
  "databinfile" varchar(32) DEFAULT NULL,
  "pdfbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_billing_printouts" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_billing_printouts_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_billing_printouts_template" FOREIGN KEY ("template") REFERENCES "crm_billing_templates" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_campaigns_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_campaigns_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_campaigns_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_campaigns_campaigns" (
  "ID" serial NOT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "datefrom" int DEFAULT '0',
  "dateto" int DEFAULT '0',
  "status" smallint DEFAULT '0',
  "replyrate" smallint DEFAULT '0',
  "projectedeffort" double precision DEFAULT '0',
  "budget" double precision DEFAULT '0',
  "description" text DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_campaigns_campaigns" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_campaigns_campaigns_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_campaigns_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_campaigns_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_campaigns_category" FOREIGN KEY ("category") REFERENCES "crm_campaigns_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_campaigns_companies" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "campaign" int NOT NULL,
  "company" int NOT NULL,
  "flag" smallint DEFAULT '0',
  CONSTRAINT "PriKey_crm_campaigns_companies" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_campaigns_companies_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_companies_campaign" FOREIGN KEY ("campaign") REFERENCES "crm_campaigns_campaigns" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_companies_company" FOREIGN KEY ("company") REFERENCES "org_contacts_companies" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_campaigns_people" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "campaign" int NOT NULL,
  "person" int NOT NULL,
  "flag" smallint DEFAULT '0',
  CONSTRAINT "PriKey_crm_campaigns_people" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_campaigns_people_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_people_campaign" FOREIGN KEY ("campaign") REFERENCES "crm_campaigns_campaigns" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_people_person" FOREIGN KEY ("person") REFERENCES "org_contacts_people" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_campaigns_records" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "campaign" int NOT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_crm_campaigns_records" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_campaigns_records_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_records_campaign" FOREIGN KEY ("campaign") REFERENCES "crm_campaigns_campaigns" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_tasks_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_org_tasks_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_tasks_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_tasks_tasks" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "parent" int DEFAULT NULL,
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "duedate" int DEFAULT '0',
  "status" smallint DEFAULT '0',
  "progress" smallint DEFAULT '0',
  "priority" smallint DEFAULT '0',
  "projectedeffort" double precision DEFAULT '0',
  "budget" double precision DEFAULT '0',
  "costs" double precision DEFAULT '0',
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_org_tasks_tasks" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_tasks_tasks_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_tasks_tasks_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_tasks_tasks_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_tasks_tasks_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_tasks_tasks_category" FOREIGN KEY ("category") REFERENCES "org_tasks_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_campaigns_tasks" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "campaign" int NOT NULL,
  "task" int NOT NULL,
  CONSTRAINT "PriKey_crm_campaigns_tasks" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_campaigns_tasks_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_tasks_campaign" FOREIGN KEY ("campaign") REFERENCES "crm_campaigns_campaigns" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_campaigns_tasks_task" FOREIGN KEY ("task") REFERENCES "org_tasks_tasks" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_cases_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_cases_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_cases_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_cases_classes" (
  "ID" serial NOT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "default" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  "inputbinfile" varchar(32) DEFAULT NULL,
  "outputbinfile" varchar(32) DEFAULT NULL,
  "pdfbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_cases_classes" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_cases_classes_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_cases_classes_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_cases_cases" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "class" int NOT NULL,
  "customer" int DEFAULT NULL,
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "casenum" varchar(255) DEFAULT NULL,
  "status" smallint DEFAULT '0',
  "priority" smallint DEFAULT '0',
  "projectedeffort" double precision DEFAULT '0',
  "budget" double precision DEFAULT '0',
  "materialcosts" double precision DEFAULT '0',
  "description" text DEFAULT NULL,
  "databinfile" varchar(32) DEFAULT NULL,
  "itemsbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_cases_cases" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_cases_cases_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_cases_cases_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_cases_cases_class" FOREIGN KEY ("class") REFERENCES "crm_cases_classes" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_cases_cases_customer" FOREIGN KEY ("customer") REFERENCES "crm_customers_customers" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_cases_cases_category" FOREIGN KEY ("category") REFERENCES "crm_cases_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_cases_records" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "case" int NOT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_crm_cases_records" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_cases_records_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_cases_records_case" FOREIGN KEY ("case") REFERENCES "crm_cases_cases" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_cases_tasks" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "case" int NOT NULL,
  "task" int NOT NULL,
  CONSTRAINT "PriKey_crm_cases_tasks" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_cases_tasks_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_cases_tasks_case" FOREIGN KEY ("case") REFERENCES "crm_cases_cases" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_cases_tasks_task" FOREIGN KEY ("task") REFERENCES "org_tasks_tasks" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_contracts_classes" (
  "ID" serial NOT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "default" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  "inputbinfile" varchar(32) DEFAULT NULL,
  "outputbinfile" varchar(32) DEFAULT NULL,
  "pdfbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_contracts_classes" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_contracts_classes_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_contracts_classes_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_contracts_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_contracts_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_contracts_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_contracts_contracts" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "class" int NOT NULL,
  "customer" int DEFAULT NULL,
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "contractnum" varchar(255) DEFAULT NULL,
  "datefrom" int DEFAULT '0',
  "usedateto" smallint DEFAULT '0',
  "dateto" int DEFAULT '0',
  "usedatecancel" smallint DEFAULT '0',
  "datecancel" int DEFAULT '0',
  "status" smallint DEFAULT '0',
  "description" text DEFAULT NULL,
  "databinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_contracts_contracts" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_contracts_contracts_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_contracts_contracts_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_contracts_contracts_class" FOREIGN KEY ("class") REFERENCES "crm_contracts_classes" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_contracts_contracts_customer" FOREIGN KEY ("customer") REFERENCES "crm_customers_customers" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_contracts_contracts_category" FOREIGN KEY ("category") REFERENCES "crm_contracts_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_contracts_records" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "contract" int NOT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_crm_contracts_records" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_contracts_records_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_contracts_records_contract" FOREIGN KEY ("contract") REFERENCES "crm_contracts_contracts" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_customers_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_customers_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_customers_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_customers_customers_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "customer" int NOT NULL,
  "category" int NOT NULL,
  CONSTRAINT "PriKey_crm_customers_customers_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_customers_customers_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_customers_customers_categories_customer" FOREIGN KEY ("customer") REFERENCES "crm_customers_customers" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_customers_customers_categories_category" FOREIGN KEY ("category") REFERENCES "crm_customers_categories" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_customers_journal" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "customer" int NOT NULL,
  "date" int DEFAULT '0',
  "label" smallint DEFAULT '0',
  "contact" int DEFAULT NULL,
  "subject" varchar(255) DEFAULT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_crm_customers_journal" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_customers_journal_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_customers_journal_customer" FOREIGN KEY ("customer") REFERENCES "crm_customers_customers" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_customers_journal_contact" FOREIGN KEY ("contact") REFERENCES "org_contacts_people" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_opportunities_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_opportunities_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_opportunities_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_opportunities_opportunities" (
  "ID" serial NOT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "customer" int DEFAULT NULL,
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "status" smallint DEFAULT '0',
  "probability" smallint DEFAULT '0',
  "closedate" int DEFAULT '0',
  "priority" smallint DEFAULT '0',
  "worstcase" double precision DEFAULT '0',
  "mostlikely" double precision DEFAULT '0',
  "upside" double precision DEFAULT '0',
  "description" text DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_crm_opportunities_opportunities" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_opportunities_opportunities_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_opportunities_opportunities_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_opportunities_opportunities_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_opportunities_opportunities_customer" FOREIGN KEY ("customer") REFERENCES "crm_customers_customers" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_opportunities_opportunities_category" FOREIGN KEY ("category") REFERENCES "crm_opportunities_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "crm_opportunities_records" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "opportunity" int NOT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_crm_opportunities_records" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_crm_opportunities_records_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_crm_opportunities_records_opportunity" FOREIGN KEY ("opportunity") REFERENCES "crm_opportunities_opportunities" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_archive_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_archive_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_archive_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_archive_locations" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_archive_locations" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_archive_locations_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_archive_rooms" (
  "ID" serial NOT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "location" int DEFAULT NULL,
  "name" varchar(255) DEFAULT NULL,
  "roomnum" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  "lastinsert" int DEFAULT '0',
  "mapbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_archive_rooms" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_archive_rooms_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_archive_rooms_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_archive_rooms_location" FOREIGN KEY ("location") REFERENCES "erp_archive_locations" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_archive_elements" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "room" int NOT NULL,
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "elementnum" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_erp_archive_elements" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_archive_elements_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_archive_elements_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_archive_elements_room" FOREIGN KEY ("room") REFERENCES "erp_archive_rooms" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_archive_elements_category" FOREIGN KEY ("category") REFERENCES "erp_archive_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_storages" (
  "ID" serial NOT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "default" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_storages" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_storages_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_storages_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_storages_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_items" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "storage" int NOT NULL,
  "deleted" smallint DEFAULT '0',
  "useserials" smallint DEFAULT '0',
  "evalmethod" smallint DEFAULT '0',
  "periode" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "manufacturer" varchar(255) DEFAULT NULL,
  "itemnum" varchar(255) DEFAULT NULL,
  "location" varchar(255) DEFAULT NULL,
  "quantity" smallint DEFAULT '0',
  "barcode" varchar(255) DEFAULT NULL,
  "sellingprice" double precision DEFAULT '0',
  "purchaseprice" double precision DEFAULT '0',
  "taxrate" double precision DEFAULT '0',
  "minstock" int DEFAULT '0',
  "weight" double precision DEFAULT '0',
  "dimx" double precision DEFAULT '0',
  "dimy" double precision DEFAULT '0',
  "dimz" double precision DEFAULT '0',
  "description" text DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_items" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_items_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_items_storage" FOREIGN KEY ("storage") REFERENCES "erp_stockcalc_storages" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_productions" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "item" int NOT NULL,
  "date" int DEFAULT '0',
  "productionnum" varchar(255) DEFAULT NULL,
  "output" int DEFAULT '0',
  "target" int DEFAULT '0',
  "materialcosts" double precision DEFAULT '0',
  "manufactcosts" double precision DEFAULT '0',
  "itemsbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_productions" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_productions_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_productions_item" FOREIGN KEY ("item") REFERENCES "erp_stockcalc_items" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_depletions" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "item" int NOT NULL,
  "delivery" int DEFAULT NULL,
  "production" int DEFAULT NULL,
  "date" int DEFAULT '0',
  "purpose" varchar(255) DEFAULT NULL,
  "amount" int DEFAULT '0',
  "price" double precision DEFAULT '0',
  CONSTRAINT "PriKey_erp_stockcalc_depletions" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_depletions_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_depletions_item" FOREIGN KEY ("item") REFERENCES "erp_stockcalc_items" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_depletions_delivery" FOREIGN KEY ("delivery") REFERENCES "crm_billing_deliveries" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_depletions_production" FOREIGN KEY ("production") REFERENCES "erp_stockcalc_productions" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_depletions_serials" (
  "ID" serial NOT NULL,
  "depletion" int NOT NULL,
  "serial" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_depletions_serials" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_depletions_serials_depletion" FOREIGN KEY ("depletion") REFERENCES "erp_stockcalc_depletions" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_devices" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "item" int NOT NULL,
  "serial" varchar(255) DEFAULT NULL,
  "location" varchar(255) DEFAULT NULL,
  "reference" varchar(255) DEFAULT NULL,
  "comment" text DEFAULT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_devices" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_devices_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_devices_item" FOREIGN KEY ("item") REFERENCES "erp_stockcalc_items" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_items_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "item" int NOT NULL,
  "category" int NOT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_items_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_items_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_items_categories_item" FOREIGN KEY ("item") REFERENCES "erp_stockcalc_items" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_items_categories_category" FOREIGN KEY ("category") REFERENCES "erp_stockcalc_categories" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_suppliers_suppliers" (
  "ID" serial NOT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "person" int DEFAULT NULL,
  "company" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "vendornum" varchar(255) DEFAULT NULL,
  "customernum" varchar(255) DEFAULT NULL,
  "dispatch" smallint DEFAULT '0',
  "payment" smallint DEFAULT '0',
  "prefcontact" smallint DEFAULT '0',
  "bank" varchar(255) DEFAULT NULL,
  "bankid" varchar(255) DEFAULT NULL,
  "account" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  "lastupload" int DEFAULT '0',
  "pricelistbinfile" varchar(32) DEFAULT NULL,
  "extdatabinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_suppliers_suppliers" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_suppliers_suppliers_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_suppliers_suppliers_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_suppliers_suppliers_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_suppliers_suppliers_person" FOREIGN KEY ("person") REFERENCES "org_contacts_people" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_suppliers_suppliers_company" FOREIGN KEY ("company") REFERENCES "org_contacts_companies" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_orders" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "item" int NOT NULL,
  "supplier" int DEFAULT NULL,
  "flag" smallint DEFAULT '0',
  "date" int DEFAULT '0',
  "ordernum" varchar(255) DEFAULT NULL,
  "amount" int DEFAULT '0',
  "delivered" int DEFAULT '0',
  "price" double precision DEFAULT '0',
  "etd" int DEFAULT '0',
  "deliverydate" int DEFAULT '0',
  CONSTRAINT "PriKey_erp_stockcalc_orders" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_orders_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_orders_item" FOREIGN KEY ("item") REFERENCES "erp_stockcalc_items" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_orders_supplier" FOREIGN KEY ("supplier") REFERENCES "erp_suppliers_suppliers" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_incoming" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "item" int NOT NULL,
  "order" int DEFAULT NULL,
  "production" int DEFAULT NULL,
  "date" int DEFAULT '0',
  "amount" int DEFAULT '0',
  "price" double precision DEFAULT '0',
  "periode" smallint DEFAULT '0',
  CONSTRAINT "PriKey_erp_stockcalc_incoming" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_incoming_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_incoming_item" FOREIGN KEY ("item") REFERENCES "erp_stockcalc_items" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_incoming_order" FOREIGN KEY ("order") REFERENCES "erp_stockcalc_orders" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_incoming_production" FOREIGN KEY ("production") REFERENCES "erp_stockcalc_productions" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_incoming_serials" (
  "ID" serial NOT NULL,
  "incoming" int NOT NULL,
  "serial" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_incoming_serials" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_incoming_serials_incoming" FOREIGN KEY ("incoming") REFERENCES "erp_stockcalc_incoming" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_templates" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  "inputbinfile" varchar(32) DEFAULT NULL,
  "outputbinfile" varchar(32) DEFAULT NULL,
  "pdfbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_templates" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_templates_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_printouts" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "template" int DEFAULT NULL,
  "ordernum" varchar(255) DEFAULT NULL,
  "databinfile" varchar(32) DEFAULT NULL,
  "pdfbinfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_printouts" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_printouts_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_printouts_template" FOREIGN KEY ("template") REFERENCES "erp_stockcalc_templates" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_stockcalc_suppliers" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "item" int NOT NULL,
  "supplier" int NOT NULL,
  CONSTRAINT "PriKey_erp_stockcalc_suppliers" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_stockcalc_suppliers_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_suppliers_item" FOREIGN KEY ("item") REFERENCES "erp_stockcalc_items" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_stockcalc_suppliers_supplier" FOREIGN KEY ("supplier") REFERENCES "erp_suppliers_suppliers" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_suppliers_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "supplier" int NOT NULL,
  "category" int NOT NULL,
  CONSTRAINT "PriKey_erp_suppliers_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_suppliers_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_suppliers_categories_supplier" FOREIGN KEY ("supplier") REFERENCES "erp_suppliers_suppliers" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_suppliers_categories_category" FOREIGN KEY ("category") REFERENCES "erp_stockcalc_categories" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_suppliers_invoices" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "supplier" int NOT NULL,
  "flag" smallint DEFAULT '0',
  "invoicenum" varchar(255) DEFAULT NULL,
  "date" int DEFAULT '0',
  "duedate" int DEFAULT '0',
  "netamount" double precision DEFAULT '0',
  "totalamount" double precision DEFAULT '0',
  "payment" double precision DEFAULT '0',
  "comment" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_erp_suppliers_invoices" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_suppliers_invoices_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_suppliers_invoices_supplier" FOREIGN KEY ("supplier") REFERENCES "erp_suppliers_suppliers" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "erp_suppliers_journal" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "supplier" int NOT NULL,
  "contact" int DEFAULT NULL,
  "date" int DEFAULT '0',
  "label" smallint DEFAULT '0',
  "subject" varchar(255) DEFAULT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_erp_suppliers_journal" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_erp_suppliers_journal_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_suppliers_journal_supplier" FOREIGN KEY ("supplier") REFERENCES "erp_suppliers_suppliers" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_erp_suppliers_journal_contact" FOREIGN KEY ("contact") REFERENCES "org_contacts_people" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_calendar_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "label" smallint DEFAULT '0',
  CONSTRAINT "PriKey_org_calendar_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_calendar_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_calendar_events" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "location" varchar(255) DEFAULT NULL,
  "datefrom" int DEFAULT '0',
  "dateto" int DEFAULT '0',
  "repeat" smallint DEFAULT '0',
  "interval" int DEFAULT '0',
  "usedaterepeat" smallint DEFAULT '0',
  "daterepeat" int DEFAULT '0',
  "display" smallint DEFAULT '0',
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_org_calendar_events" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_calendar_events_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_calendar_events_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_calendar_events_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_calendar_events_category" FOREIGN KEY ("category") REFERENCES "org_calendar_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_calendar_invitations" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) NOT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "event" int NOT NULL,
  "flag" smallint DEFAULT '0',
  CONSTRAINT "PriKey_org_calendar_invitations" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_calendar_invitations_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_calendar_invitations_event" FOREIGN KEY ("event") REFERENCES "org_calendar_events" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_contacts_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_org_contacts_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_contacts_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_contacts_companies_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "company" int NOT NULL,
  "category" int NOT NULL,
  CONSTRAINT "PriKey_org_contacts_companies_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_contacts_companies_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_companies_categories_company" FOREIGN KEY ("company") REFERENCES "org_contacts_companies" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_companies_categories_category" FOREIGN KEY ("category") REFERENCES "org_contacts_categories" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_contacts_people_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "person" int NOT NULL,
  "category" int NOT NULL,
  CONSTRAINT "PriKey_org_contacts_people_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_contacts_people_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_people_categories_person" FOREIGN KEY ("person") REFERENCES "org_contacts_people" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_people_categories_category" FOREIGN KEY ("category") REFERENCES "org_contacts_categories" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_contacts_people_companies" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "person" int NOT NULL,
  "company" int NOT NULL,
  CONSTRAINT "PriKey_org_contacts_people_companies" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_contacts_people_companies_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_people_companies_person" FOREIGN KEY ("person") REFERENCES "org_contacts_people" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_contacts_people_companies_company" FOREIGN KEY ("company") REFERENCES "org_contacts_companies" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_followup_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_org_followup_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_followup_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_followup_reminders" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "duedate" int DEFAULT '0',
  "status" smallint DEFAULT '0',
  "priority" smallint DEFAULT '0',
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_org_followup_reminders" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_followup_reminders_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_followup_reminders_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_followup_reminders_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_followup_reminders_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_followup_reminders_category" FOREIGN KEY ("category") REFERENCES "org_followup_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_followup_records" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "reminder" int NOT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_org_followup_records" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_followup_records_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_followup_records_reminder" FOREIGN KEY ("reminder") REFERENCES "org_followup_reminders" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_links_linklists" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_org_links_linklists" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_links_linklists_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_links_linklists_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_links_linklists_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_links_links" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "linklist" int NOT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "url" varchar(255) DEFAULT NULL,
  "description" text DEFAULT NULL,
  "numviews" int DEFAULT '0',
  CONSTRAINT "PriKey_org_links_links" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_links_links_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_links_links_linklist" FOREIGN KEY ("linklist") REFERENCES "org_links_linklists" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_links_view" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) NOT NULL,
  "linklist" int NOT NULL,
  CONSTRAINT "PriKey_org_links_view" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_links_view_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_links_view_linklist" FOREIGN KEY ("linklist") REFERENCES "org_links_linklists" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_notes_categories" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_org_notes_categories" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_notes_categories_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_notes_notes" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "assigneduser" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "category" int DEFAULT NULL,
  "deleted" smallint DEFAULT '0',
  "title" varchar(255) DEFAULT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_org_notes_notes" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_notes_notes_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_notes_notes_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_notes_notes_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_notes_notes_assigneduser" FOREIGN KEY ("assigneduser") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_notes_notes_category" FOREIGN KEY ("category") REFERENCES "org_notes_categories" ("ID") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_tasks_clocking" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "task" int NOT NULL,
  "flag" smallint DEFAULT '0',
  "date" int DEFAULT '0',
  "subject" varchar(255) DEFAULT NULL,
  "actualeffort" double precision DEFAULT '0',
  CONSTRAINT "PriKey_org_tasks_clocking" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_tasks_clocking_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_tasks_clocking_task" FOREIGN KEY ("task") REFERENCES "org_tasks_tasks" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "org_tasks_records" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "task" int NOT NULL,
  "text" text DEFAULT NULL,
  CONSTRAINT "PriKey_org_tasks_records" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_org_tasks_records_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_org_tasks_records_task" FOREIGN KEY ("task") REFERENCES "org_tasks_tasks" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "platform_accesskeys" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "key" varchar(32) DEFAULT NULL,
  "description" text DEFAULT NULL,
  CONSTRAINT "PriKey_platform_accesskeys" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_platform_accesskeys_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "platform_associates" (
  "ID" serial NOT NULL,
  "entity1" varchar(60) DEFAULT NULL,
  "index1" int DEFAULT '0',
  "entity2" varchar(60) DEFAULT NULL,
  "index2" int DEFAULT '0',
  CONSTRAINT "PriKey_platform_associates" PRIMARY KEY ("ID")
);

CREATE TABLE "platform_boarditems" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "text" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_platform_boarditems" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_platform_boarditems_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "platform_charts" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "activity" smallint DEFAULT '0',
  "timeoriented" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "type" smallint DEFAULT '0',
  "binfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_platform_charts" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_platform_charts_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "platform_exporttemplates" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "activity" smallint DEFAULT '0',
  "entity" varchar(60) DEFAULT NULL,
  "name" varchar(255) DEFAULT NULL,
  "binfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_platform_exporttemplates" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_platform_exporttemplates_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "platform_monitor" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) DEFAULT NULL,
  "ownergroup" varchar(60) DEFAULT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "UMI" varchar(60) DEFAULT NULL,
  "entity" varchar(60) DEFAULT NULL,
  "index" int DEFAULT '0',
  "url" varchar(255) DEFAULT NULL,
  "name" varchar(255) DEFAULT NULL,
  "action" smallint DEFAULT '0',
  CONSTRAINT "PriKey_platform_monitor" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_platform_monitor_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_platform_monitor_ownergroup" FOREIGN KEY ("ownergroup") REFERENCES "platform_groups" ("groupname") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_platform_monitor_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "platform_services" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "activity" smallint DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  "event" smallint DEFAULT '0',
  "entity" varchar(60) DEFAULT NULL,
  "schedule" int DEFAULT '0',
  "interval" int DEFAULT '0',
  "binfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_platform_services" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_platform_services_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "platform_services_accesskeys" (
  "ID" serial NOT NULL,
  "creator" varchar(60) DEFAULT NULL,
  "creationdate" int DEFAULT '0',
  "service" int NOT NULL,
  "accesskey" int NOT NULL,
  CONSTRAINT "PriKey_platform_services_accesskeys" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_platform_services_accesskeys_creator" FOREIGN KEY ("creator") REFERENCES "platform_users" ("username") ON DELETE SET NULL ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_platform_services_accesskeys_service" FOREIGN KEY ("service") REFERENCES "platform_services" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE,
  CONSTRAINT "ForKey_platform_services_accesskeys_accesskey" FOREIGN KEY ("accesskey") REFERENCES "platform_accesskeys" ("ID") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "platform_settings" (
  "ID" serial NOT NULL,
  "owneruser" varchar(60) NOT NULL,
  "creationdate" int DEFAULT '0',
  "lastmodified" int DEFAULT '0',
  "UMI" varchar(60) DEFAULT NULL,
  "binfile" varchar(32) DEFAULT NULL,
  CONSTRAINT "PriKey_platform_settings" PRIMARY KEY ("ID"),
  CONSTRAINT "ForKey_platform_settings_owneruser" FOREIGN KEY ("owneruser") REFERENCES "platform_users" ("username") ON DELETE CASCADE ON UPDATE CASCADE DEFERRABLE
);

CREATE TABLE "platform_tags" (
  "ID" serial NOT NULL,
  "entity" varchar(60) DEFAULT NULL,
  "index" int DEFAULT '0',
  "name" varchar(255) DEFAULT NULL,
  CONSTRAINT "PriKey_platform_tags" PRIMARY KEY ("ID")
);

CREATE INDEX "Index_platform_associates_entity1" ON "platform_associates" ("entity1");
CREATE INDEX "Index_platform_associates_index1" ON "platform_associates" ("index1");
CREATE INDEX "Index_platform_associates_entity2" ON "platform_associates" ("entity2");
CREATE INDEX "Index_platform_associates_index2" ON "platform_associates" ("index2");
CREATE INDEX "Index_platform_monitor_index" ON "platform_monitor" ("index");
CREATE INDEX "Index_platform_tags_entity" ON "platform_tags" ("entity");
CREATE INDEX "Index_platform_tags_index" ON "platform_tags" ("index");